Functions
==========



ECG
-------

.. automodule:: neurokit2.ecg
   :members: 

PPG
-------

.. automodule:: neurokit2.ppg
   :members: 

HRV
------------------------

.. automodule:: neurokit2.hrv
   :members:   
   
RSP
-------

.. automodule:: neurokit2.rsp
   :members: 

EDA
-------

.. automodule:: neurokit2.eda
   :members: 

EMG
-------

.. automodule:: neurokit2.emg
   :members: 


EEG
-------

.. automodule:: neurokit2.eeg
   :members: 


Signal Processing
--------------------------

.. automodule:: neurokit2.signal
   :members: 

Events
-------

.. automodule:: neurokit2.events
   :members: 

Data
----------

.. automodule:: neurokit2.data
   :members: 

Epochs
-----------

.. automodule:: neurokit2.epochs
   :members: 

Statistics
-----------

.. automodule:: neurokit2.stats
   :members: 
   
Complexity
-----------

.. automodule:: neurokit2.complexity
   :members: 

Miscellaneous
--------------

.. automodule:: neurokit2.bio
   :members:  


.. automodule:: neurokit2.misc
   :members: 
